@@ -459,7 +459,8 @@ void Application::desktopManager(bool enabled) {
             // NOTE: there are two modes
             // When virtual desktop is used (all screens are combined to form a large virtual desktop),
             // we only create one DesktopWindow. Otherwise, we create one for each screen.
-            if(primaryScreen() && primaryScreen()->virtualSiblings().size() > 1) {
+            // Under Wayland, separate desktops are created for avoiding problems.
+            if(!underWayland_ && primaryScreen() && primaryScreen()->virtualSiblings().size() > 1) {
                 DesktopWindow* window = createDesktopWindow(-1);
                 desktopWindows_.push_back(window);
             }
@@ -934,7 +935,8 @@ void Application::onScreenAdded(QScreen* newScreen) {
         connect(newScreen, &QScreen::availableGeometryChanged, this, &Application::onAvailableGeometryChanged);
         connect(newScreen, &QObject::destroyed, this, &Application::onScreenDestroyed);
         const auto siblings = primaryScreen()->virtualSiblings();
-        if(siblings.contains(newScreen)) { // the primary screen is changed
+        if(!underWayland_ // Under Wayland, separate desktops are created for avoiding problems.
+           && siblings.contains(newScreen)) { // the primary screen is changed
             if(desktopWindows_.size() == 1) {
                 desktopWindows_.at(0)->setGeometry(newScreen->virtualGeometry());
                 if(siblings.size() > 1) { // a virtual desktop is created
@@ -1065,7 +1067,8 @@ static int sigterm_fd[2];
 
 static void sigtermHandler(int) {
     char c = 1;
-    ::write(sigterm_fd[0], &c, sizeof(c));
+    auto w = ::write(sigterm_fd[0], &c, sizeof(c));
+    Q_UNUSED(w);
 }
 
 void Application::installSigtermHandler() {
@@ -1090,7 +1093,8 @@ void Application::onSigtermNotified() {
     if(QSocketNotifier* notifier = qobject_cast<QSocketNotifier*>(sender())) {
         notifier->setEnabled(false);
         char c;
-        ::read(sigterm_fd[1], &c, sizeof(c));
+        auto r = ::read(sigterm_fd[1], &c, sizeof(c));
+        Q_UNUSED(r);
         // close all windows cleanly; otherwise, we might get this warning:
         // "QBasicTimer::start: QBasicTimer can only be used with threads started with QThread"
         const auto windows = topLevelWidgets();
