@@ -28,9 +28,9 @@
 #include <QSettings>
 #include <QStandardPaths>
 
-#include <libfm-qt/folderview.h>
-#include <libfm-qt/core/terminal.h>
-#include <libfm-qt/core/archiver.h>
+#include <libfm-qt6/folderview.h>
+#include <libfm-qt6/core/terminal.h>
+#include <libfm-qt6/core/archiver.h>
 
 namespace PCManFM {
 
@@ -54,6 +54,11 @@ PreferencesDialog::PreferencesDialog(const QString& activePage, QWidget* parent)
 
     selectPage(activePage);
     adjustSize();
+
+    if(static_cast<Application*>(qApp)->underWayland()) {
+        ui.suCommand->setEnabled(false);
+        ui.suLabel->setEnabled(false);
+    }
 }
 
 PreferencesDialog::~PreferencesDialog() = default;
